==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/UserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UserFluentImpl<A extends io.fabric8.openshift.api.model.UserFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.UserFluent<A>{
  public UserFluentImpl() {
  }
  public UserFluentImpl(io.fabric8.openshift.api.model.User instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withFullName(instance.getFullName()); 
    this.withGroups(instance.getGroups()); 
    this.withIdentities(instance.getIdentities()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String fullName;
  private java.util.List<java.lang.String> groups = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> identities = new java.util.ArrayList<java.lang.String>();
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getFullName() {
    return this.fullName;
  }
  public A withFullName(java.lang.String fullName) {
    this.fullName=fullName; return (A) this;
  }
  public java.lang.Boolean hasFullName() {
    return this.fullName != null;
  }
  
  /**
   * Method is deprecated. use withFullName instead.
   */
  @java.lang.Deprecated
  public A withNewFullName(java.lang.String arg0) {
    return (A)withFullName(new String(arg0));
  }
  public A addToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.add(index, item);
    return (A)this;
  }
  public A setToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.set(index, item); return (A)this;
  }
  public A addToGroups(java.lang.String... items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A addAllToGroups(java.util.Collection<java.lang.String> items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A removeFromGroups(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGroups() {
    return this.groups;
  }
  public java.lang.String getGroup(java.lang.Integer index) {
    return this.groups.get(index);
  }
  public java.lang.String getFirstGroup() {
    return this.groups.get(0);
  }
  public java.lang.String getLastGroup() {
    return this.groups.get(groups.size() - 1);
  }
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGroups(java.util.List<java.lang.String> groups) {
    if (groups != null) {this.groups = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
  }
  public A withGroups(java.lang.String... groups) {
    if (this.groups != null) {this.groups.clear();}
    if (groups != null) {for (java.lang.String item :groups){ this.addToGroups(item);}} return (A) this;
  }
  public java.lang.Boolean hasGroups() {
    return groups != null && !groups.isEmpty();
  }
  public A addNewGroup(java.lang.String arg0) {
    return (A)addToGroups(new String(arg0));
  }
  public A addToIdentities(java.lang.Integer index,java.lang.String item) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    this.identities.add(index, item);
    return (A)this;
  }
  public A setToIdentities(java.lang.Integer index,java.lang.String item) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    this.identities.set(index, item); return (A)this;
  }
  public A addToIdentities(java.lang.String... items) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.identities.add(item);} return (A)this;
  }
  public A addAllToIdentities(java.util.Collection<java.lang.String> items) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.identities.add(item);} return (A)this;
  }
  public A removeFromIdentities(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.identities!= null){ this.identities.remove(item);}} return (A)this;
  }
  public A removeAllFromIdentities(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.identities!= null){ this.identities.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getIdentities() {
    return this.identities;
  }
  public java.lang.String getIdentity(java.lang.Integer index) {
    return this.identities.get(index);
  }
  public java.lang.String getFirstIdentity() {
    return this.identities.get(0);
  }
  public java.lang.String getLastIdentity() {
    return this.identities.get(identities.size() - 1);
  }
  public java.lang.String getMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: identities) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: identities) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withIdentities(java.util.List<java.lang.String> identities) {
    if (identities != null) {this.identities = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : identities){this.addToIdentities(item);}} else { this.identities = null;} return (A) this;
  }
  public A withIdentities(java.lang.String... identities) {
    if (this.identities != null) {this.identities.clear();}
    if (identities != null) {for (java.lang.String item :identities){ this.addToIdentities(item);}} return (A) this;
  }
  public java.lang.Boolean hasIdentities() {
    return identities != null && !identities.isEmpty();
  }
  public A addNewIdentity(java.lang.String arg0) {
    return (A)addToIdentities(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.UserFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.UserFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UserFluentImpl that = (UserFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (fullName != null ? !fullName.equals(that.fullName) :that.fullName != null) return false;
    if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
    if (identities != null ? !identities.equals(that.identities) :that.identities != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  fullName,  groups,  identities,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) UserFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/UserFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class UserFluentImpl<A extends io.fabric8.openshift.api.model.UserFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.UserFluent<A>{
  public UserFluentImpl() {
  }
  public UserFluentImpl(io.fabric8.openshift.api.model.User instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withFullName(instance.getFullName()); 
    this.withGroups(instance.getGroups()); 
    this.withIdentities(instance.getIdentities()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String fullName;
  private java.util.List<java.lang.String> groups = new java.util.ArrayList<java.lang.String>();
  private java.util.List<java.lang.String> identities = new java.util.ArrayList<java.lang.String>();
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.ObjectMetaBuilder metadata;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getFullName() {
    return this.fullName;
  }
  public A withFullName(java.lang.String fullName) {
    this.fullName=fullName; return (A) this;
  }
  public java.lang.Boolean hasFullName() {
    return this.fullName != null;
  }
  
  /**
   * Method is deprecated. use withFullName instead.
   */
  @java.lang.Deprecated
  public A withNewFullName(java.lang.String arg0) {
    return (A)withFullName(new String(arg0));
  }
  public A addToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.add(index, item);
    return (A)this;
  }
  public A setToGroups(java.lang.Integer index,java.lang.String item) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    this.groups.set(index, item); return (A)this;
  }
  public A addToGroups(java.lang.String... items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A addAllToGroups(java.util.Collection<java.lang.String> items) {
    if (this.groups == null) {this.groups = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.groups.add(item);} return (A)this;
  }
  public A removeFromGroups(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public A removeAllFromGroups(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.groups!= null){ this.groups.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getGroups() {
    return this.groups;
  }
  public java.lang.String getGroup(java.lang.Integer index) {
    return this.groups.get(index);
  }
  public java.lang.String getFirstGroup() {
    return this.groups.get(0);
  }
  public java.lang.String getLastGroup() {
    return this.groups.get(groups.size() - 1);
  }
  public java.lang.String getMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingGroup(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: groups) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withGroups(java.util.List<java.lang.String> groups) {
    if (groups != null) {this.groups = new java.util.ArrayList(); for (java.lang.String item : groups){this.addToGroups(item);}} else { this.groups = null;} return (A) this;
  }
  public A withGroups(java.lang.String... groups) {
    if (this.groups != null) {this.groups.clear();}
    if (groups != null) {for (java.lang.String item :groups){ this.addToGroups(item);}} return (A) this;
  }
  public java.lang.Boolean hasGroups() {
    return groups != null && !groups.isEmpty();
  }
  public A addNewGroup(java.lang.String arg0) {
    return (A)addToGroups(new String(arg0));
  }
  public A addToIdentities(java.lang.Integer index,java.lang.String item) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    this.identities.add(index, item);
    return (A)this;
  }
  public A setToIdentities(java.lang.Integer index,java.lang.String item) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    this.identities.set(index, item); return (A)this;
  }
  public A addToIdentities(java.lang.String... items) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.identities.add(item);} return (A)this;
  }
  public A addAllToIdentities(java.util.Collection<java.lang.String> items) {
    if (this.identities == null) {this.identities = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.identities.add(item);} return (A)this;
  }
  public A removeFromIdentities(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.identities!= null){ this.identities.remove(item);}} return (A)this;
  }
  public A removeAllFromIdentities(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.identities!= null){ this.identities.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getIdentities() {
    return this.identities;
  }
  public java.lang.String getIdentity(java.lang.Integer index) {
    return this.identities.get(index);
  }
  public java.lang.String getFirstIdentity() {
    return this.identities.get(0);
  }
  public java.lang.String getLastIdentity() {
    return this.identities.get(identities.size() - 1);
  }
  public java.lang.String getMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: identities) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingIdentity(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: identities) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withIdentities(java.util.List<java.lang.String> identities) {
    if (identities != null) {this.identities = new java.util.ArrayList(); for (java.lang.String item : identities){this.addToIdentities(item);}} else { this.identities = null;} return (A) this;
  }
  public A withIdentities(java.lang.String... identities) {
    if (this.identities != null) {this.identities.clear();}
    if (identities != null) {for (java.lang.String item :identities){ this.addToIdentities(item);}} return (A) this;
  }
  public java.lang.Boolean hasIdentities() {
    return identities != null && !identities.isEmpty();
  }
  public A addNewIdentity(java.lang.String arg0) {
    return (A)addToIdentities(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.ObjectMeta getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.kubernetes.api.model.ObjectMeta buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.kubernetes.api.model.ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.UserFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return new io.fabric8.openshift.api.model.UserFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.kubernetes.api.model.ObjectMetaBuilder().build());
  }
  public io.fabric8.openshift.api.model.UserFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.kubernetes.api.model.ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    UserFluentImpl that = (UserFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (fullName != null ? !fullName.equals(that.fullName) :that.fullName != null) return false;
    if (groups != null ? !groups.equals(that.groups) :that.groups != null) return false;
    if (identities != null ? !identities.equals(that.identities) :that.identities != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  fullName,  groups,  identities,  kind,  metadata,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl<io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.UserFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.kubernetes.api.model.ObjectMeta item) {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.ObjectMetaBuilder(this);
    }
    io.fabric8.kubernetes.api.model.ObjectMetaBuilder builder;
    public N and() {
      return (N) UserFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}
